==> spread-5.7.0.72-py3-none-any.whl: spread_core/bam/recipe.py <==
from spread_core.mqtt.spread.address import ProviderAddress
from spread_core.mqtt.spread.topic import State
from spread_core.mqtt.spread.variable import Variable


class Recipe:
    def __init__(self, project_id: int, _manager_type: str, manager_id: int, _type: str, _id: int):
        self.id = _id
        self.project_id = project_id
        self.manager_type = _manager_type
        self.manager_id = manager_id
        self.provider_type = _type
        self._engineries = []
        self._las = []
        self._level = None
        self._guarded = None

    def __str__(self):
        return f'{self.__class__.__name__}<{self.id}>: {str(self._engineries)}'

    def dispatch_state(self, topic: State, variable: Variable):
        if topic.entity_address.funit_type in ("BrightnessLevel", "CurrentLuminosity", "CurrentPresence"):
            self._level = variable.value

        elif topic.entity_address.funit_type in ("Guard", "On"):
            self._guarded = variable.value

        for eng in self._engineries:
            eng.on_state(topic, variable)

        for la in self._las:
            la.on_state(topic, variable)

    @property
    def level(self):
        return self._level

    @property
    def guarded(self):
        return self._guarded

    @property
    def is_bonded(self):
        return bool(self._engineries)

    def set_ingredient(self, eng):
        if eng.__class__.__name__ == "LightingArea":
            self._las.append(eng)
        else:
            self._engineries.append(eng)

    def get_address(self, funit_type):
        return ProviderAddress(
            self.project_id,
            self.manager_type,
            self.manager_id,
            self.provider_type,
            self.id,
            funit_type
        )

==> spread-5.9.0.59-py3-none-any.whl: spread_core/bam/recipe.py <==
from spread_core.mqtt.spread.address import ProviderAddress
from spread_core.mqtt.spread.topic import State
from spread_core.mqtt.spread.variable import Variable


class Recipe:
    def __init__(self, project_id: int, _manager_type: str, manager_id: int, _type: str, _id: int):
        self.id = _id
        self.project_id = project_id
        self.manager_type = _manager_type
        self.manager_id = manager_id
        self.provider_type = _type
        self._engineries = []
        self._las = []
        self._level = None
        self._guarded = None

    def __str__(self):
        return f'{self.__class__.__name__}<{self.id}>: {str(self._engineries)}'

    def dispatch_state(self, topic: State, variable: Variable):
        if topic.entity_address.funit_type in ("BrightnessLevel", "CurrentLuminosity", "CurrentPresence"):
            self._level = variable.value

        elif topic.entity_address.funit_type == "Guard":
            self._guarded = variable.value

        elif topic.entity_address.funit_type == "On":
            self._guarded = variable.value
            if variable.value is True:
                self._level = 254
            elif variable.value is False:
                self._level = 0
            else:
                self._level = None

        for eng in self._engineries:
            eng.on_state(topic, variable)

        for la in self._las:
            la.on_state(topic, variable)

    @property
    def level(self):
        return self._level

    @property
    def guarded(self):
        return self._guarded

    @property
    def is_bonded(self):
        return bool(self._engineries)

    def set_ingredient(self, eng):
        if eng.__class__.__name__ == "LightingArea":
            self._las.append(eng)
        else:
            self._engineries.append(eng)

    def get_address(self, funit_type):
        return ProviderAddress(
            self.project_id,
            self.manager_type,
            self.manager_id,
            self.provider_type,
            self.id,
            funit_type
        )
